==> SyL-0.10.0.tar.gz: SyL/include/lib/Xml/Rss/SyL_XmlRssClient.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_XmlRssClient.php,v 1.1 2007/03/17 13:53:07 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * HTTP饤ȥ饹
 */
require_once dirname(__FILE__) . '/../../Http/SyL_HttpClient.php';

/**
 * RSS 饤ȥ饹
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_XmlRssClient.php,v 1.1 2007/03/17 13:53:07 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_XmlRssClient extends SyL_HttpClient
{
    /**
     * ̥֥Ȥ
     * 
     * @access public
     * @param string 쥹ݥ󥹥ǡ
     * @param string 饤ȥ󥳡
     * @param string RSSС
     */
    function &createResult(&$data, $client_encode='', $rss_version='')
    {
        include_once 'SyL_XmlRssClientResult.php';
        $result =& new SyL_XmlRssClientResult($data, $client_encode, $rss_version);
        return $result;
    }

}

?>

==> SyL-0.14.5.tar.gz: SyL/include/lib/Xml/Rss/SyL_XmlRssClient.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_XmlRssClient.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * HTTP饤ȥ饹
 */
require_once dirname(__FILE__) . '/../../Http/SyL_HttpClient.php';

/**
 * RSS 饤ȥ饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_XmlRssClient.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_XmlRssClient extends SyL_HttpClient
{
    /**
     * RSSС
     * 
     * @access private
     * @var string
     */
    var $rss_version = '';

    /**
     * RSSС򥻥å
     * 
     * @access public
     * @param string RSSС
     */
    function setVersion($rss_version)
    {
        $this->rss_version = $rss_version;
    }

    /**
     * ̥֥Ȥ
     * 
     * @access public
     * @param string 쥹ݥ󥹥ǡ
     * @param string 饤ȥ󥳡
     * @param string RSSС
     */
    function &createResult(&$data, $client_encode='')
    {
        include_once 'SyL_XmlRssClientResult.php';
        $result =& new SyL_XmlRssClientResult($data, $client_encode, $this->rss_version);
        return $result;
    }

}

?>
